@@ -2,7 +2,7 @@
  KWin - the KDE window manager
  This file is part of the KDE project.
 
- Copyright (C) 2008 Martin Gräßlin <ubuntu@martin-graesslin.com
+ Copyright (C) 2008 Martin Gräßlin <mgraesslin@kde.org>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -45,9 +45,6 @@ public:
 public slots:
     virtual void save();
 
-private slots:
-    void thumbnailsChanged();
-
 private:
     CoverSwitchEffectConfigForm* m_ui;
 };
